pub struct MlFeatureName(/* private fields */);Implementations
Sourceimpl MlFeatureName
impl MlFeatureName
Sourcepub fn new(value: impl AsRef<str>) -> Result<MlFeatureName, MlFeatureError>
pub fn new(value: impl AsRef<str>) -> Result<MlFeatureName, MlFeatureError>
Examples found in repository?
examples/basic_usage.rs (line 5)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4 let dataset = MlDatasetName::new("iris")?;
5 let feature = MlFeatureName::new("sepal_width")?;
6 let model = MlModelName::new("baseline-classifier")?;
7 let shape = TensorShape::new([150, 4])?;
8
9 assert_eq!(dataset.as_str(), "iris");
10 assert_eq!(feature.as_str(), "sepal_width");
11 assert_eq!(model.as_str(), "baseline-classifier");
12 assert_eq!(shape.dims(), &[150, 4]);
13 Ok(())
14}Sourcepub fn as_str(&self) -> &str
pub fn as_str(&self) -> &str
Examples found in repository?
examples/basic_usage.rs (line 10)
3fn main() -> Result<(), Box<dyn std::error::Error>> {
4 let dataset = MlDatasetName::new("iris")?;
5 let feature = MlFeatureName::new("sepal_width")?;
6 let model = MlModelName::new("baseline-classifier")?;
7 let shape = TensorShape::new([150, 4])?;
8
9 assert_eq!(dataset.as_str(), "iris");
10 assert_eq!(feature.as_str(), "sepal_width");
11 assert_eq!(model.as_str(), "baseline-classifier");
12 assert_eq!(shape.dims(), &[150, 4]);
13 Ok(())
14}Trait Implementations
Sourceimpl AsRef<str> for MlFeatureName
impl AsRef<str> for MlFeatureName
Sourceimpl Clone for MlFeatureName
impl Clone for MlFeatureName
Sourcefn clone(&self) -> MlFeatureName
fn clone(&self) -> MlFeatureName
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MlFeatureName
impl Debug for MlFeatureName
Sourceimpl Display for MlFeatureName
impl Display for MlFeatureName
Sourceimpl FromStr for MlFeatureName
impl FromStr for MlFeatureName
Sourcetype Err = MlFeatureError
type Err = MlFeatureError
The associated error which can be returned from parsing.
Sourcefn from_str(
value: &str,
) -> Result<MlFeatureName, <MlFeatureName as FromStr>::Err>
fn from_str( value: &str, ) -> Result<MlFeatureName, <MlFeatureName as FromStr>::Err>
Parses a string
s to return a value of this type. Read moreSourceimpl Hash for MlFeatureName
impl Hash for MlFeatureName
Sourceimpl Ord for MlFeatureName
impl Ord for MlFeatureName
Sourcefn cmp(&self, other: &MlFeatureName) -> Ordering
fn cmp(&self, other: &MlFeatureName) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MlFeatureName
impl PartialEq for MlFeatureName
Sourcefn eq(&self, other: &MlFeatureName) -> bool
fn eq(&self, other: &MlFeatureName) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MlFeatureName
impl PartialOrd for MlFeatureName
Sourceimpl TryFrom<&str> for MlFeatureName
impl TryFrom<&str> for MlFeatureName
Sourcetype Error = MlFeatureError
type Error = MlFeatureError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: &str,
) -> Result<MlFeatureName, <MlFeatureName as TryFrom<&str>>::Error>
fn try_from( value: &str, ) -> Result<MlFeatureName, <MlFeatureName as TryFrom<&str>>::Error>
Performs the conversion.
impl Eq for MlFeatureName
impl StructuralPartialEq for MlFeatureName